@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::TOMLParsingModules;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,19 +8,19 @@ our $results = [
     "OK",
     [
       {
-        errors => 3.1e-06,
-        participant => "TOML",
-        rate => 800,
+        errors => 3.2e-06,
+        participant => "TOML::Parser",
+        rate => 770,
         samples => 20,
-        time => 1200,
+        time => 1300,
         vs_slowest => 1,
       },
       {
-        errors => 1.4e-06,
-        participant => "TOML::Parser",
-        rate => 820,
+        errors => 2e-06,
+        participant => "TOML",
+        rate => 780,
         samples => 20,
-        time => 1200,
+        time => 1300,
         vs_slowest => 1,
       },
     ],
@@ -31,6 +31,7 @@ our $results = [
                                             scenario_module => "TOMLParsingModules",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -104,18 +105,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -124,7 +125,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3235.746,
+                                              speed                        => 3301.507,
                                               stepping                     => 7,
                                             },
                                             {
@@ -199,18 +200,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -219,7 +220,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2991.257,
+                                              speed                        => 3292.614,
                                               stepping                     => 7,
                                             },
                                             {
@@ -294,18 +295,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -314,7 +315,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2280.074,
+                                              speed                        => 3282.775,
                                               stepping                     => 7,
                                             },
                                             {
@@ -389,18 +390,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -409,45 +410,45 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2148.808,
+                                              speed                        => "3298.480",
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.111171007156372,
+      "func.elapsed_time"              => 0.112104177474976,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.036,
+                                            "__PACKAGE__" => 1.041,
                                             "Bencher::Scenario::TOMLParsingModules" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "File::Slurper" => 0.008,
-                                            "perl" => "v5.24.0",
+                                            "File::Slurper" => 0.009,
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                             "TOML" => 0.97,
-                                            "TOML::Parser" => "0.10",
+                                            "TOML::Parser" => 0.91,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "dataset", [0]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -457,9 +458,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1494334711,
       "func.scenario_module_sha1sum"   => "e04f5205b682aa411be9a1c7b04a22186c270148",
       "func.scenario_module_sha256sum" => "359d8e1398dafc55bbbf330e2216fabf09080fbb4d5ed972a12eb9ac0e1dce47",
-      "func.time_end"                  => 1494338840.2042,
+      "func.time_end"                  => 1554781051.2563,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1494338840.09303,
+      "func.time_start"                => 1554781051.1442,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "\x{3BC}s"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
